@@ -3,7 +3,7 @@
 # Filename: AutoInit_GBase8s.sh
 # Function: Auto install GBase 8s software and auto init database.
 # Write by: liaosnet@gbasedbt.com
-# Version : 1.4.13   update date: 2025-05-23
+# Version : 1.4.14   update date: 2025-07-03
 ##################################################################
 ##### Defind env
 export LANG=C
@@ -139,6 +139,10 @@ _loginfo "Datadir: $DATADIR"
 ##### Get env
 NUMCPU=$(awk '/^processor/{i++}END{printf("%d\n",i)}' /proc/cpuinfo)
 NUMMEM=$(awk '/^MemTotal:/{printf("%d\n",$2/1000)}' /proc/meminfo)
+NUMNODE=1
+if [ -x /usr/bin/lscpu -o -x /usr/sbin/lscpu ]; then 
+  NUMNODE=$(lscpu | awk '/NUMA node(s)/{print $NF}')
+fi
 
 if [ x"${USER_INST}" = "xsmall" ]; then
   NUMCPU=1
@@ -185,8 +189,12 @@ elif [ $NUMCPU -le 4 ]; then
   CPUVP=$NUMCPU
   CFG_NETPOOL=1
 else
-  CPUVP=$(expr $NUMCPU - 1)
-  CFG_NETPOOL=$(expr $NUMCPU / 3)
+  if [ ${NUMNODE} -gt 2 ]; then 
+    CPUVP=$(expr ${NUMCPU} \* 2 / ${NUMNODE})
+  else 
+    CPUVP=$(expr ${NUMCPU} - 1)
+  fi
+  CFG_NETPOOL=$(expr ${NUMCPU} / 3)
   [ ${CFG_NETPOOL} -gt 10 ] && CFG_NETPOOL=10
 fi
 
@@ -282,6 +290,9 @@ chown ${USER_NAME}:${USER_NAME} $INSTALL_DIR 2>/dev/null
 chmod 0755 $INSTALL_DIR 2>/dev/null
 
 # ids_install
+mkdir /${USER_NAME}TMP 2>/dev/null
+chown ${USER_NAME}:${USER_NAME} /${USER_NAME}TMP 2>/dev/null
+chmod 1775 /${USER_NAME}TMP 2>/dev/null
 mkdir -p ${WORKDIR}/tmp 2>/dev/null
 export IATEMPDIR=${WORKDIR}/tmp
 export LD_LIBRARY_PATH=/usr/lib64:/usr/lib:/lib64:/lib:/lib/x86_64-linux-gnu:/lib/aarch64-linux-gnu:$LD_LIBRARY_PATH
@@ -298,7 +309,10 @@ if [ ! $? -eq 0 ]; then
 fi
 
 if [ -f ${INSTALL_DIR}/etc/alarmprogram.sh ]; then
-  sed -i "s#ksh#sh#g" ${INSTALL_DIR}/etc/alarmprogram.sh
+  sed -i "s#/ksh#/sh#g" ${INSTALL_DIR}/etc/alarmprogram.sh
+fi
+if [ -f ${INSTALL_DIR}/bin/onshutdown.sh ]; then
+  sed -i "s#/ksh#/sh#g" ${INSTALL_DIR}/bin/onshutdown.sh
 fi
 
 ###### Init database
@@ -418,8 +432,8 @@ do
   sleep 3
   echo -e ".\c"
   NUMDB=$(su - ${USER_NAME} -c 'echo "select count(*) numdb from sysdatabases;" | dbaccess sysmaster - 2>/dev/null')
-  NUMDB=$(echo $NUMDB | awk '{printf("%d\n",$2)}')
-  if [ ${NUMDB} -gt 3 ]; then
+  NUMDB=$(echo $NUMDB | awk '{print $NF}')
+  if [ ${NUMDB:-0} -gt 3 ]; then
     break
   else
     sleep 3
@@ -566,7 +580,7 @@ sed -i "s#^SYSSBSPACENAME.*#SYSSBSPACENAME sbspace01#g" $CFGFILE
 sed -i "s#^MULTIPROCESSOR.*#MULTIPROCESSOR 1#g" $CFGFILE
 sed -i "s#^AUTO_TUNE.*#AUTO_TUNE 0#g" $CFGFILE
 sed -i "/^AUTO_TUNE/a\AUTO_REPREPARE 1" $CFGFILE
-sed -i "s#^CLEANERS.*#CLEANERS 32#g" $CFGFILE
+sed -i "s#^CLEANERS.*#CLEANERS 128#g" $CFGFILE
 sed -i "s#^STACKSIZE.*#STACKSIZE 1024#g" $CFGFILE
 sed -i "s#^ALLOW_NEWLINE.*#ALLOW_NEWLINE 1#g" $CFGFILE
 sed -i "s#^DS_MAX_QUERIES.*#DS_MAX_QUERIES 5#g" $CFGFILE
