@@ -3,7 +3,7 @@
 # Filename: CleanAll.sh
 # Function: Clean GBase 8s Auto Install.
 # Write by: liaosnet@gbasedbt.com
-# Version : 1.4.13   update date: 2024-06-28
+# Version : 1.4.13   update date: 2025-06-09
 ##################################################################
 ##### Define Parameter
 ##### Get Parameter
@@ -38,7 +38,12 @@ if [ $? -gt 0 ];then
     exit 2
 fi
 
-INSTALL_DIR=$(head -n 1 /${USER_UPPER}TMP/.infxdirs)
+if [ -f /${USER_NAME}TMP/.infxdirs ]; then
+  INSTALL_DIR=$(head -n 1 /${USER_UPPER}TMP/.infxdirs)
+else
+  echo ".infxdirs not found !"
+  exit 3
+fi
 
 su - ${USER_NAME} -c "onmode -ky" 2>/dev/null
 su - ${USER_NAME} -c "onclean -ky" 2>/dev/null
